@@ -20,6 +20,7 @@ from prettytable import (
     ORGMODE,
     PLAIN_COLUMNS,
     RANDOM,
+    SINGLE_BORDER,
     PrettyTable,
     from_csv,
     from_db_cursor,
@@ -882,6 +883,80 @@ class TestHtmlOutput:
         </tr>
     </tbody>
 </table>
+""".strip()  # noqa: E501
+        )
+
+    def test_HtmlOutputWithTitle(self):
+        t = helper_table()
+        t.title = "Title"
+        result = t.get_html_string()
+        assert (
+            result.strip()
+            == """
+<table>
+    <caption>Title</caption>
+    <thead>
+        <tr>
+            <th>Field 1</th>
+            <th>Field 2</th>
+            <th>Field 3</th>
+        </tr>
+    </thead>
+    <tbody>
+        <tr>
+            <td>value 1</td>
+            <td>value2</td>
+            <td>value3</td>
+        </tr>
+        <tr>
+            <td>value 4</td>
+            <td>value5</td>
+            <td>value6</td>
+        </tr>
+        <tr>
+            <td>value 7</td>
+            <td>value8</td>
+            <td>value9</td>
+        </tr>
+    </tbody>
+</table>
+""".strip()
+        )
+
+    def test_HtmlOutputFormattedWithTitle(self):
+        t = helper_table()
+        t.title = "Title"
+        result = t.get_html_string(format=True)
+        assert (
+            result.strip()
+            == """
+<table frame="box" rules="cols">
+    <caption>Title</caption>
+    <thead>
+        <tr>
+            <th style="padding-left: 1em; padding-right: 1em; text-align: center">Field 1</th>
+            <th style="padding-left: 1em; padding-right: 1em; text-align: center">Field 2</th>
+            <th style="padding-left: 1em; padding-right: 1em; text-align: center">Field 3</th>
+        </tr>
+    </thead>
+    <tbody>
+        <tr>
+            <td style="padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top">value 1</td>
+            <td style="padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top">value2</td>
+            <td style="padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top">value3</td>
+        </tr>
+        <tr>
+            <td style="padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top">value 4</td>
+            <td style="padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top">value5</td>
+            <td style="padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top">value6</td>
+        </tr>
+        <tr>
+            <td style="padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top">value 7</td>
+            <td style="padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top">value8</td>
+            <td style="padding-left: 1em; padding-right: 1em; text-align: center; vertical-align: top">value9</td>
+        </tr>
+    </tbody>
+</table>
 """.strip()  # noqa: E501
         )
 
@@ -1121,6 +1196,18 @@ value 7         value8         value9
 ║ value 4 ║  value5 ║  value6 ║
 ║ value 7 ║  value8 ║  value9 ║
 ╚═════════╩═════════╩═════════╝
+""",
+            ),
+            pytest.param(
+                SINGLE_BORDER,
+                """
+┌─────────┬─────────┬─────────┐
+│ Field 1 │ Field 2 │ Field 3 │
+├─────────┼─────────┼─────────┤
+│ value 1 │  value2 │  value3 │
+│ value 4 │  value5 │  value6 │
+│ value 7 │  value8 │  value9 │
+└─────────┴─────────┴─────────┘
 """,
             ),
         ],
